@@ -736,21 +736,23 @@ class StandardAcquisition(BaseAcquisition):
             return None, None
         self._check_has_metadata()
         with self.read_entry() as entry:
-            if self._DISTANCE_PATH in entry:
-                node = entry[self._DISTANCE_PATH]
-                distance = h5py_read_dataset(node)
-                unit = self._get_unit(node, default_unit="cm")
-                # convert to meter
-                distance = distance * metricsystem.MetricSystem.from_value(unit).value
-                return distance, "m"
+            for key in self.configuration.sample_detector_distance_paths:
+                if key in entry:
+                    node = entry[key]
+                    distance = h5py_read_dataset(node)
+                    unit = self._get_unit(node, default_unit="cm")
+                    # convert to meter
+                    distance = (
+                        distance * metricsystem.MetricSystem.from_value(unit).value
+                    )
+                    return distance, "m"
+            mess = "unable to find distance for entry {}.".format(entry)
+            if self.raise_error_if_issue:
+                raise ValueError(mess)
             else:
-                mess = "unable to find distance for entry {}.".format(entry)
-                if self.raise_error_if_issue:
-                    raise ValueError(mess)
-                else:
-                    mess += "Default value will be set (1m)"
-                    _logger.warning(mess)
-                    return 1.0, "m"
+                mess += "Default value will be set (1m)"
+                _logger.warning(mess)
+                return 1.0, "m"
 
     def _get_pixel_size(self, axis):
         """return tuple(pixel_size, unit)"""
