@@ -398,7 +398,15 @@ class _H5ToNxConverter:
 
                 entry_type = get_entry_type(url=url, configuration=self.configuration)
                 if self.configuration.is_xrdc_ct:
-                    if (
+                    if entry_type is AcquisitionStep.INITIALIZATION:
+                        current_acquisition = None
+                        _logger.warning(
+                            "Found several acquisition type "
+                            "in the same file. Stop conversion at"
+                            " {}".format(url)
+                        )
+                        break
+                    elif (
                         not self._ignore_entry_frm_titles(group_name)
                         and current_acquisition is None
                         or current_acquisition.is_different_sequence(url)
