@@ -202,6 +202,8 @@ class HDF5Config:
 
     Y_PIXEL_SIZE_KEYS_DK = "y_pixel_keys"
 
+    SAMPLE_DETECTOR_DISTANCE_DK = "sample_detector_distance"
+
     COMMENTS_ENTRIES_TITLES_SECTION = {
         ENTRIES_AND_TITLES_SECTION_DK: "optional section \n"
         "# define titles meaning. Titles allows frame type deduction for each group.\n",
@@ -216,6 +218,7 @@ class HDF5Config:
         ALIGNMENT_TITLES_DK: "List of title to consider the group/entry as an alignment.  Ignored if dark_groups, flat_groups, projection_groups ... are provided.",
         X_PIXEL_SIZE_KEYS_DK: "List of keys / paths to look for the x pixel size",
         Y_PIXEL_SIZE_KEYS_DK: "List of keys / paths to look for the y pixel size",
+        SAMPLE_DETECTOR_DISTANCE_DK: "List of keys / paths to look for sample to detector distance",
     }
 
     # FRAMES TYPE SECTION
@@ -254,6 +257,7 @@ class HDF5Config:
     EXTRA_PARAMS_ENERGY_DK = "energy"
     EXTRA_PARAMS_X_PIXEL_SIZE_DK = "x_pixel_size"
     EXTRA_PARAMS_Y_PIXEL_SIZE_DK = "y_pixel_size"
+    EXTRA_PARAMS_DISTANCE = "detector_sample_distance"
 
     EXTRA_PARAMS_ENERGY_VALID_KEYS = (
         EXTRA_PARAMS_ENERGY_DK,
@@ -295,6 +299,7 @@ class HDF5Config:
         self._y_rot_key = settings.H5_Y_ROT_KEY
         self._diode_keys = settings.H5_DIODE_KEYS
         self._expo_time_keys = settings.H5_ACQ_EXPO_TIME_KEYS
+        self._sample_detector_distance_keys = settings.H5_DISTANCE_KEYS
 
         # information regarding titles
         self._entries = None
@@ -455,9 +460,14 @@ class HDF5Config:
 
     @valid_camera_names.setter
     def valid_camera_names(self, names: Union[None, Iterable]) -> None:
-        if not isinstance(names, (Iterable, type(None))):
+        if names == "None":
+            self._valid_camera_names = None
+        elif isinstance(names, str):
+            raise TypeError("'names' should be None or an instance of Iterable")
+        elif not isinstance(names, (Iterable, type(None))):
             raise TypeError("'names' should be None or an instance of Iterable")
         else:
+            assert not isinstance(names, str), "'{}'".format(names)
             self._valid_camera_names = names
 
     @property
@@ -686,6 +696,17 @@ class HDF5Config:
         else:
             self._y_pixel_size_paths = paths
 
+    @property
+    def sample_detector_distance_paths(self):
+        return self._sample_detector_distance_keys
+
+    @sample_detector_distance_paths.setter
+    def sample_detector_distance_paths(self, paths):
+        if not isinstance(paths, Iterable):
+            raise TypeError("'paths should be an Iterable")
+        else:
+            self._sample_detector_distance_keys = paths
+
     # frame type definition
 
     def _parse_frame_urls(self, urls: tuple):
@@ -811,6 +832,7 @@ class HDF5Config:
                 HDF5Config.ACQUISITION_EXPO_TIME_KEYS_DK: self.exposition_time_keys,
                 HDF5Config.X_PIXEL_SIZE_KEYS_DK: self.x_pixel_size_paths,
                 HDF5Config.Y_PIXEL_SIZE_KEYS_DK: self.y_pixel_size_paths,
+                HDF5Config.SAMPLE_DETECTOR_DISTANCE_DK: self.sample_detector_distance_paths,
             },
             self.ENTRIES_AND_TITLES_SECTION_DK: {
                 HDF5Config.ENTRIES_DK: self.entries or "",
@@ -935,10 +957,11 @@ class HDF5Config:
         # handle valid camera names. empty string is consider as a valid value
         valid_camera_names = dict_.get(HDF5Config.VALID_CAMERA_DK, None)
         if valid_camera_names == "":
+            valid_camera_names = None
+        else:
             valid_camera_names = convert_str_to_tuple(
                 valid_camera_names, none_if_empty=True
             )
-            valid_camera_names = None
         self.valid_camera_names = valid_camera_names
         # handle rotation angles.
         rotation_angle_keys = dict_.get(HDF5Config.ROT_ANGLE_DK, None)
@@ -992,6 +1015,15 @@ class HDF5Config:
                 y_pixel_size_paths, none_if_empty=True
             )
             self.y_pixel_size_paths = y_pixel_size_paths
+        # handle sample detector distance
+        sample_detector_distance = dict_.get(
+            HDF5Config.SAMPLE_DETECTOR_DISTANCE_DK, None
+        )
+        if sample_detector_distance is not None:
+            sample_detector_distance = convert_str_to_tuple(
+                sample_detector_distance, none_if_empty=True
+            )
+            self.sample_detector_distance_paths = sample_detector_distance
 
     def load_entries_titles_section(self, dict_):
         # handle entries to convert
@@ -1064,7 +1096,7 @@ class HDF5Config:
 
     @staticmethod
     def dict_to_cfg(file_path, dict_):
-        """"""
+        """ """
         if not file_path.lower().endswith((".cfg", ".config")):
             _logger.warning("add a valid extension to the output file")
             file_path += ".cfg"
