@@ -68,6 +68,9 @@ acquisition"""
 H5_DIODE_KEYS = ("fpico3",)
 """keys used by bliss to store diode dataset"""
 
+H5_DISTANCE_KEYS = ("technique/scan/sample_detector_distance",)
+"""keys used by bliss to store the sample to detector distance"""
+
 H5_ACQ_EXPO_TIME_KEYS = ("acq_expo_time",)
 
 H5_INIT_TITLES = (
